@@ -58,6 +58,7 @@ __END__
 
 Algorithm::Easing::Backdraft - Calculate eased translations between two positive whole integer values over time
 
+=back
 =head1 SYNOPSIS
 
         ## with mediator
@@ -76,7 +77,7 @@ Algorithm::Easing::Backdraft - Calculate eased translations between two positive
         my $b = 0;
 
         # change
-        my $c = 0;
+        my $c = 240;
 
         # time passed in seconds as a real positive integer between each frame
         my $frame_time = 0.0625;
@@ -90,58 +91,80 @@ Algorithm::Easing::Backdraft - Calculate eased translations between two positive
             ...;
         }
 
-=item ease_none()
-
-    Usage -- the expected parameters are as follows : 
-        t = time
-        b = begin
-        c = change
-        d = duration
-        
-    $obj->ease_none($t,$b,$c,$d);
+=back
+=over 2
+=item ease_none
+    Usage :
+    
+        Arguments : 
+            t = time,
+            b = begin,
+            c = change,
+            d = duration,
+        Return :
+            p = position,
+            
+        my $p = $obj->ease_both($t,$b,$c,$d);
 
 This method is used for a linear translation between two positive real whole integers using a positive real integer as the parameter for time.
 
-=item ease_in()
-
-    Usage -- the expected parameters are as follows : 
-        t = time
-        b = begin
-        c = change
-        d = duration
-        
-    $obj->ease_in($t,$b,$c,$d);
+=back
+=over 2
+=item ease_in
+    Usage :
+    
+        Arguments : 
+            t = time,
+            b = begin,
+            c = change,
+            d = duration,
+        Return :
+            p = position,
+            
+        my $p = $obj->ease_both($t,$b,$c,$d);
 
 This method is used for a eased translation between two positive real whole integers as an inward tween using a positive real integer as the parameter for time.
 
-=item ease_out()
-
-    Usage -- the expected parameters are as follows : 
-        t = time
-        b = begin
-        c = change
-        d = duration
-        
-    $obj->ease_out($t,$b,$c,$d);
+=back
+=over 2
+=item ease_out
+    Usage :
+    
+        Arguments : 
+            t = time,
+            b = begin,
+            c = change,
+            d = duration,
+        Return :
+            p = position,
+            
+        my $p = $obj->ease_both($t,$b,$c,$d);
 
 This method is used for a eased translation between two positive real whole integers as an outward tween using a positive real integer as the parameter for time.
 
-=item ease_both()
-
-    Usage -- the expected parameters are as follows : 
-        t = time
-        b = begin
-        c = change
-        d = duration
-        
-    $obj->ease_both($t,$b,$c,$d);
+=back
+=over 2
+=item ease_both
+    Usage :
+    
+        Arguments : 
+            t = time,
+            b = begin,
+            c = change,
+            d = duration,
+        Return :
+            p = position,
+            
+        my $p = $obj->ease_both($t,$b,$c,$d);
 
 This method is used for a eased translation between two positive real whole integers as an inward then outward tween using a positive real integer as the parameter for time.
 
+=back
 =head1 AUTHOR
 
 Jason McVeigh, <jmcveigh@outlook.com>
 
+=back
 =head1 COPYRIGHT AND LICENSE
 
 Copyright 2016 by Jason McVeigh
@@ -149,4 +172,5 @@ Copyright 2016 by Jason McVeigh
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
 
+=back
 =cut
\ No newline at end of file
