@@ -42,8 +42,6 @@ sub ease_both  {
 
 1;
 
-
-
 __END__
 
 # MAN3 POD
@@ -52,6 +50,7 @@ __END__
 
 Algorithm::Easing::Sinusoidal - Calculate eased translations between two positive whole integer values over time
 
+=back
 =head1 SYNOPSIS
 
         ## with mediator
@@ -70,7 +69,7 @@ Algorithm::Easing::Sinusoidal - Calculate eased translations between two positiv
         my $b = 0;
 
         # change
-        my $c = 0;
+        my $c = 240;
 
         # time passed in seconds as a real positive integer between each frame
         my $frame_time = 0.0625;
@@ -83,52 +82,71 @@ Algorithm::Easing::Sinusoidal - Calculate eased translations between two positiv
             # plot
             ...;
         }
-
-=item ease_none()
-
-    Usage -- the expected parameters are as follows : 
-        t = time
-        b = begin
-        c = change
-        d = duration
-        
-    $obj->ease_none($t,$b,$c,$d);
+=back
+=over 2
+=item ease_none
+    Usage :
+    
+        Arguments : 
+            t = time,
+            b = begin,
+            c = change,
+            d = duration,
+        Return :
+            p = position,
+            
+        my $p = $obj->ease_both($t,$b,$c,$d);
 
 This method is used for a linear translation between two positive real whole integers using a positive real integer as the parameter for time.
 
-=item ease_in()
-
-    Usage -- the expected parameters are as follows : 
-        t = time
-        b = begin
-        c = change
-        d = duration
-        
-    $obj->ease_in($t,$b,$c,$d);
+=back
+=over 2
+=item ease_in
+    Usage :
+    
+        Arguments : 
+            t = time,
+            b = begin,
+            c = change,
+            d = duration,
+        Return :
+            p = position,
+            
+        my $p = $obj->ease_both($t,$b,$c,$d);
 
 This method is used for a eased translation between two positive real whole integers as an inward tween using a positive real integer as the parameter for time.
 
-=item ease_out()
-
-    Usage -- the expected parameters are as follows : 
-        t = time
-        b = begin
-        c = change
-        d = duration
-        
-    $obj->ease_out($t,$b,$c,$d);
+=back
+=over 2
+=item ease_out
+    Usage :
+    
+        Arguments : 
+            t = time,
+            b = begin,
+            c = change,
+            d = duration,
+        Return :
+            p = position,
+            
+        my $p = $obj->ease_both($t,$b,$c,$d);
 
 This method is used for a eased translation between two positive real whole integers as an outward tween using a positive real integer as the parameter for time.
 
-=item ease_both()
-
-    Usage -- the expected parameters are as follows : 
-        t = time
-        b = begin
-        c = change
-        d = duration
-        
-    $obj->ease_both($t,$b,$c,$d);
+=back
+=over 2
+=item ease_both
+    Usage :
+    
+        Arguments : 
+            t = time,
+            b = begin,
+            c = change,
+            d = duration,
+        Return :
+            p = position,
+            
+        my $p = $obj->ease_both($t,$b,$c,$d);
 
 This method is used for a eased translation between two positive real whole integers as an inward then outward tween using a positive real integer as the parameter for time.
 
@@ -136,6 +154,7 @@ This method is used for a eased translation between two positive real whole inte
 
 Jason McVeigh, <jmcveigh@outlook.com>
 
+=back
 =head1 COPYRIGHT AND LICENSE
 
 Copyright 2016 by Jason McVeigh
@@ -143,4 +162,5 @@ Copyright 2016 by Jason McVeigh
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
 
+=back
 =cut
\ No newline at end of file
